vfbLib.parsers.glyph.GlyphAnchorsParser
=======================================

.. currentmodule:: vfbLib.parsers.glyph

.. autoclass:: GlyphAnchorsParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlyphAnchorsParser.__init__
      ~GlyphAnchorsParser.parse
      ~GlyphAnchorsParser.parse_hex
      ~GlyphAnchorsParser.read_double
      ~GlyphAnchorsParser.read_doubles
      ~GlyphAnchorsParser.read_float
      ~GlyphAnchorsParser.read_floats
      ~GlyphAnchorsParser.read_int16
      ~GlyphAnchorsParser.read_int32
      ~GlyphAnchorsParser.read_int8
      ~GlyphAnchorsParser.read_str
      ~GlyphAnchorsParser.read_str_all
      ~GlyphAnchorsParser.read_uint16
      ~GlyphAnchorsParser.read_uint32
      ~GlyphAnchorsParser.read_uint8
      ~GlyphAnchorsParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GlyphAnchorsParser.encoding
      ~GlyphAnchorsParser.master_count
      ~GlyphAnchorsParser.stream
      ~GlyphAnchorsParser.ttStemsH_count
      ~GlyphAnchorsParser.ttStemsV_count
   
   